==> qtweather_0.7.6.tar.gz: qtweather-0.7.6/src/mainwindow.h <==
#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QDomDocument>
#include <QSignalMapper>
#include <QNetworkAccessManager>
#include <QNetworkRequest>
#include <QNetworkReply>
#include <QResizeEvent>
#include <QLabel>
#include <QUrl>
#include <QSettings>
#include "progressdialog.h"
#include "stackedwindow.h"
#include "dayperiod.h"

namespace Ui {
    class MainWindow;
}

class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit MainWindow(QWidget *parent = 0);
    ~MainWindow();

protected:
    virtual void resizeEvent(QResizeEvent * event);

signals:
    void uiReady();

private:
    Ui::MainWindow *ui;
    QSettings* settings;
    QDomDocument *doc;
    QNetworkAccessManager *manager;
    QSignalMapper* mapper;
    QString zipCode;
    QString zipCache;
    QString *latlon;
    QString *wfo;
    QString *zcode;
    QList<DayPeriod*>* dayPeriods;
    QPixmap** iconCache; //array of icon pointers
    QIcon *icon;
    bool needShowList;
    bool justStarted;
    ProgressDialog *pg;

    void detailWindow(int day);
    void setDomDocument(QString* reply);
    void deleteCache();
    void colorize(QLabel* label);
    void parse_for_wfo(QDomElement* domElement);
    QList<QString*>* parse_for_temps(QDomElement* domElement);
    QList<QString*>* parse_for_days(QDomElement* domElement);
    QList<QString*>* parse_for_precip(QDomElement* domElement);
    QString* parse_for_city(QDomElement* domElement);

private slots:
    void gotCoordinates();
    void gotXML();
    void setDayIcons(int dayIndex);
    void setFIcon();
    void setTempGraph();

    void dayClick(QModelIndex index);
    void changeZip();
    void setSettings();
    void visitNAOO();
//    void zipEvent(){
//        changeZip();
//    }


};

#endif // MAINWINDOW_H

==> qtweather_0.7.8.tar.gz: qtweather-0.7.8/src/mainwindow.h <==
#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QDomDocument>
#include <QSignalMapper>
#include <QNetworkAccessManager>
#include <QNetworkRequest>
#include <QNetworkReply>
#include <QResizeEvent>
#include <QLabel>
#include <QUrl>
#include <QSettings>
#include "progressdialog.h"
#include "stackedwindow.h"
#include "dayperiod.h"

namespace Ui {
    class MainWindow;
}

class MainWindow : public QMainWindow
{
    Q_OBJECT
	static const int HOME_1 = 1;
	static const int HOME_2 = 2;

public:
    explicit MainWindow(QWidget *parent = 0);
    ~MainWindow();
	static void colorize(QLabel* label);

protected:
    virtual void resizeEvent(QResizeEvent * event);

signals:
    void uiReady();

private:
    Ui::MainWindow *ui;
    QSettings* settings;
    QDomDocument *doc;
    QNetworkAccessManager *manager;
    QSignalMapper* mapper;
    QString zipCode;
    QString zipCache;
    QString *latlon;
    QString *wfo;
    QString *zcode;
    QList<DayPeriod*>* dayPeriods;
    QPixmap** iconCache; //array of icon pointers
    QIcon *icon;
    bool needShowList;
	int mostRecentHome;
    ProgressDialog *pg;

    void detailWindow(int day);
    void setDomDocument(QString* reply);
	void deleteCache();
    void parse_for_wfo(QDomElement* domElement);
    QList<QString*>* parse_for_temps(QDomElement* domElement);
    QList<QString*>* parse_for_days(QDomElement* domElement);
    QList<QString*>* parse_for_precip(QDomElement* domElement);
    QString* parse_for_city(QDomElement* domElement);

private slots:
    void gotCoordinates();
    void gotXML();
    void setDayIcons(int dayIndex);
    void setFIcon();
    void setTempGraph();

    void dayClick(QModelIndex index);
	void changeZip(const char zipcode[] = 0);
    void setSettings();
	void visitNAOO();
	void otherHome();


};

#endif // MAINWINDOW_H
